@@ -5,8 +5,6 @@
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 #
 
-Xvfb :99 >/dev/null 2>&1 &
-export DISPLAY=:99
 export PL_PATH=`which perl`
 export TB_PATH=${TB_PATH:-`which thunderbird`}
 
@@ -14,13 +12,5 @@ if [ `id -u` -eq 0 ]; then
   echo "Warning: Running the test suite as root may cause some tests to fail."
 fi
 
-if [ "$#" -eq 0 ]; then
-  util/run-tests.py
-else
-  util/run-tests.py $@
-fi
+util/run-tests.py "$@"
 
-RESULT=$?
-
-killall Xvfb
-exit $RESULT
